@@ -1,4 +1,5 @@
 import stesting
+import schooltool.common
 from zope.i18nmessageid import MessageFactory
 GradebookMessage = MessageFactory("schooltool.gradebook")
 
@@ -14,12 +15,4 @@ def registerTestSetup():
 registerTestSetup()
 del registerTestSetup
 
-def makeDecimalARock():
-    # XXX this is insecure
-    from decimal import Decimal
-    from zope.security.checker import NoProxy
-    import zope.security
-    zope.security.checker.BasicTypes[Decimal] = NoProxy
-
-makeDecimalARock()
-del makeDecimalARock
+schooltool.common.register_lauchpad_project(__package__, 'schooltool.gradebook')
