@@ -43,6 +43,7 @@ from zope.traversing.browser.absoluteurl import absoluteURL
 from zope.viewlet import viewlet
 from zope.i18n.interfaces.locales import ICollator
 from zope.i18n import translate
+from zope.authentication.interfaces import IUnauthenticatedPrincipal
 
 import zc.resourcelibrary
 from zc.table.column import GetterColumn
@@ -61,7 +62,6 @@ from schooltool.gradebook import interfaces
 from schooltool.gradebook.activity import ensureAtLeastOneWorksheet
 from schooltool.gradebook.activity import createSourceString, getSourceObj
 from schooltool.gradebook.activity import Worksheet, LinkedColumnActivity
-from schooltool.gradebook.browser.report_utils import buildHTMLParagraphs
 from schooltool.gradebook.gradebook import (getCurrentSectionTaught,
     setCurrentSectionTaught, getCurrentSectionAttended,
     setCurrentSectionAttended)
@@ -78,6 +78,7 @@ from schooltool import table
 from schooltool.term.interfaces import ITerm, IDateManager
 from schooltool.report.report import ReportLinkViewlet
 from schooltool.skin import flourish
+from schooltool.skin.flourish.report import buildHTMLParagraphs
 
 from schooltool.gradebook import GradebookMessage as _
 
@@ -101,7 +102,8 @@ def getColumnKeys(gradebook):
 
 def convertAverage(average, scoresystem):
     """converts average to display value of the given scoresystem"""
-    if scoresystem is None:
+    if (scoresystem is None or
+        not IDiscreteValuesScoreSystem.providedBy(scoresystem)):
         return '%.1f%%' % average
     for score in scoresystem.scores:
         if average >= score[3]:
@@ -670,7 +672,7 @@ class GradebookOverview(SectionFinder, JSONScoresBase):
 
         if ICommentScoreSystem.providedBy(insecure_activity.scoresystem):
             self.needs_comments = True
-            zc.resourcelibrary.need("fckeditor")
+            zc.resourcelibrary.need("ckeditor")
 
         return {
             'linked_source': None,
@@ -1491,6 +1493,8 @@ class FlourishMyGradesView(MyGradesView, flourish.page.Page):
 
     def update(self):
         """Handle change of year."""
+        if IUnauthenticatedPrincipal.providedBy(self.request.principal):
+            raise Unauthorized("user not logged in")
         self.person = IPerson(self.request.principal)
         if self.handleYearChange():
             return
