@@ -25,6 +25,7 @@ from zope.container.interfaces import INameChooser
 from zope.browserpage.viewpagetemplatefile import ViewPageTemplateFile
 from zope.component import adapts
 from zope.interface import Interface, implements
+from zope.lifecycleevent.interfaces import IObjectRemovedEvent
 from zope.schema import Choice, Int
 from zope.security.checker import canWrite
 from zope.security.interfaces import Unauthorized
@@ -47,6 +48,7 @@ from schooltool.schoolyear.interfaces import ISchoolYearContainer
 from schooltool.skin import flourish
 from schooltool.skin.flourish.page import TertiaryNavigationManager
 from schooltool.term.interfaces import ITerm
+from schooltool.term.term import listTerms
 from schooltool.schoolyear.subscriber import ObjectEventAdapterSubscriber
 
 from schooltool.gradebook.interfaces import (IGradebookRoot,
@@ -199,7 +201,7 @@ class FlourishReportSheetsBase(ActiveSchoolYearContentMixin):
                     'checked': not sheet.hidden,
                     'terms': [False] * len(schoolyear),
                     })
-                for index, term in enumerate(schoolyear.values()):
+                for index, term in enumerate(listTerms(schoolyear)):
                     deployedKey = '%s_%s' % (schoolyear.__name__, term.__name__)
                     if sheet.__name__.startswith(deployedKey):
                         deployment['terms'][index] = True
@@ -272,7 +274,7 @@ class FlourishReportSheetsView(FlourishReportSheetsBase, flourish.page.Page):
             'title': _('-- Entire year --'),
             'selected': 'selected',
             }]
-        for term in self.schoolyear.values():
+        for term in listTerms(self.schoolyear):
             result.append({
                 'name': term.__name__,
                 'title': term.title,
@@ -326,10 +328,10 @@ class FlourishReportSheetsView(FlourishReportSheetsBase, flourish.page.Page):
                     new_index = 1
                 elif len(rest) > 1 and rest[0] == '-' and rest[1:].isdigit():
                     new_index = int(rest[1:])
-            else:
-                new_index = 0
-            if new_index > title_index:
-                title_index = new_index
+                else:
+                    new_index = 0
+                if new_index > title_index:
+                    title_index = new_index
 
         # copy worksheet template to the term or whole year
         if term:
@@ -396,6 +398,10 @@ class FlourishHideUnhideReportSheetsView(FlourishReportSheetsBase,
                   mapping={'year': self.schoolyear.title})
         return translate(title, context=self.request)
 
+    @property
+    def terms(self):
+        return listTerms(self.schoolyear)
+
     def update(self):
         if 'CANCEL' in self.request:
             self.request.response.redirect(self.nextURL())
@@ -424,11 +430,13 @@ class FlourishHideUnhideReportSheetsView(FlourishReportSheetsBase,
             if sheet.__name__ == deployedKey:
                 for section in ISectionContainer(term).values():
                     activities = IActivities(section)
-                    activities[deployedKey].hidden = sheet.hidden
+                    if deployedKey in activities:
+                        activities[deployedKey].hidden = sheet.hidden
                 return
 
     def nextURL(self):
-        return absoluteURL(self.context, self.request) + '/report_sheets'
+        return self.url_with_schoolyear_id(self.context,
+                                           view_name='report_sheets')
 
 
 class FlourishTemplatesView(flourish.page.Page):
@@ -1123,7 +1131,9 @@ class FlourishLayoutReportCardView(flourish.page.Page,
         if source == TARDY_KEY:
             return TARDY_HEADING
         termName, worksheetName, activityName = source.split('|')
-        term = self.schoolyear[termName]
+        term = self.schoolyear.get(termName)
+        if term is None: # maybe term was deleted
+            return
         root = IGradebookRoot(ISchoolToolApplication(None))
         worksheet = root.deployed[worksheetName]
         if activityName == AVERAGE_KEY:
@@ -1151,9 +1161,12 @@ class FlourishLayoutReportCardView(flourish.page.Page,
         else:
             current_columns  = []
         for index, column in enumerate(current_columns):
+            sourceName = self.getSourceName(column.source)
+            if sourceName is None:
+                continue
             result = {
                 'source_index': index + 1,
-                'source_value': self.getSourceName(column.source),
+                'source_value': sourceName,
                 'source_edit': self.getEditURL('Column', index),
                 'heading_value': column.heading,
                 }
@@ -1171,9 +1184,12 @@ class FlourishLayoutReportCardView(flourish.page.Page,
         else:
             current_activities  = []
         for index, activity in enumerate(current_activities):
+            sourceName = self.getSourceName(activity.source)
+            if sourceName is None:
+                continue
             result = {
                 'source_index': index + 1,
-                'source_value': self.getSourceName(activity.source),
+                'source_value': sourceName,
                 'source_edit': self.getEditURL('Activity', index),
                 'heading_value': activity.heading,
                 }
@@ -1295,7 +1311,7 @@ class FlourishReportCardLayoutMixin(ActiveSchoolYearContentMixin):
         else:
             source = source_obj.source
         root = IGradebookRoot(ISchoolToolApplication(None))
-        for term in self.schoolyear.values():
+        for term in listTerms(self.schoolyear):
             deployedKey = '%s_%s' % (self.schoolyear.__name__, term.__name__)
             for key in root.deployed:
                 if key.startswith(deployedKey):
@@ -1467,9 +1483,32 @@ class SectionAddedSubscriber(ObjectEventAdapterSubscriber):
         for key in root.deployed:
             if key.startswith(deployedKey):
                 deployedWorksheet = root.deployed[key]
-                if deployedWorksheet.hidden:
-                    continue
                 worksheetCopy = Worksheet(deployedWorksheet.title)
                 worksheetCopy.deployed = True
+                worksheetCopy.hidden = deployedWorksheet.hidden
                 activities[key] = worksheetCopy
                 copyActivities(deployedWorksheet, worksheetCopy)
+
+
+class RemoveLayoutColumnsWhenTermIsRemoved(ObjectEventAdapterSubscriber):
+
+    adapts(IObjectRemovedEvent, ITerm)
+
+    def __call__(self):
+        return
+        root = IGradebookRoot(ISchoolToolApplication(None))
+        schoolyear = ISchoolYear(self.object)
+        layout = root.layouts.get(schoolyear.__name__)
+        if layout is not None:
+            self.remove_term_columns(layout.columns)
+            self.remove_term_columns(layout.outline_activities)
+
+    def remove_term_columns(self, layout_columns):
+        columns = layout_columns[:]
+        for column in columns:
+            source = column.source
+            if source in (ABSENT_KEY, TARDY_KEY):
+                continue
+            termName, worksheetName, activityName = source.split('|')
+            if termName == self.object.__name__:
+                layout_columns.remove(column)
