@@ -157,7 +157,7 @@ class FailingTextScoreValidator(z3c.form.validator.SimpleFieldValidator):
                 _("${value} is not valid in ${scoresystem}.",
                     mapping={
                         'value': value,
-                        'scoresystem': scoresystem.description or scoresystem.title,
+                        'scoresystem': scoresystem.title,
                     }),
                 value)
         return z3c.form.validator.SimpleFieldValidator.validate(self, value)
@@ -543,3 +543,12 @@ class FlourishRequestReportSheetsExportView(RequestXLSReportDialog):
 
     report_builder = 'export_report_sheets.xls'
 
+
+class FlourishRequestReportCardView(RequestRemoteReportDialog):
+
+    report_builder = 'report_card.pdf'
+
+
+class FlourishRequestStudentDetailReportView(RequestRemoteReportDialog):
+
+    report_builder = 'student_detail.pdf'
